@@ -3,6 +3,7 @@ from typing import List, Optional
 
 from pydantic import BaseModel, validate_arguments
 
+from ..cache import cache
 from ..core import BaseClient
 from ..types import AccountType, Currency
 
@@ -13,6 +14,7 @@ class Institution(BaseModel):
     institution_id: str
     display_name: str
     currency: Optional[Currency]
+    account_ids: List[str]
     account_types: List[AccountType]
 
 
@@ -34,6 +36,7 @@ class BaseInstitutionsResource(ABC):
         self._client = client
 
     @validate_arguments
+    @cache
     async def _get(self, user_uuid: str) -> List[Institution]:
         async with self._client.session() as session:
             response = await session.get(PATH.format(user_uuid=user_uuid))
