@@ -5,6 +5,7 @@ from typing import List, Optional, Sequence, Set
 
 from pydantic import BaseModel, validate_arguments
 
+from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
 from ..types import AccountType, Currency, Impact
@@ -17,7 +18,7 @@ class TransactionRecord(BaseModel):
     description: Optional[str]
     amount: int
     impact: Impact
-    account_number: str
+    account_id: str
     account_type: Optional[AccountType]
     currency: Optional[Currency]
     labels: Set[str]
@@ -35,7 +36,7 @@ class TransactionsMeta(BaseModel):
 
 
 class TransactionsAccount(BaseModel):
-    account_number: str
+    account_id: str
     account_type: Optional[AccountType]
     records: List[TransactionRecord]
 
@@ -78,6 +79,7 @@ class BaseTransactionsResource(ABC):
         return TransactionsResponse(**response.json())
 
     @validate_arguments
+    @cache
     async def _get(
         self,
         user_uuid: str,
